##  Acting on Data Quality Issues
Click any card to filter and view the fact sheets you are subscribed to that have missing data.
Review the fact sheets and fill in missing data by updating incomplete fields and adding required relations. You can do so by either:
  * Editing certain attributes directly in the inventory table view. To learn more about table view, see [Bulk Updating Data in Inventory Table View](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD "Table View lets you view and edit multiple fact sheets in a spreadsheet-like format—perfect for scanning, comparing, and updating data quickly and efficiently.")
  * Opening the fact sheet for more detailed editing. See [Adding and Editing Data in Fact Sheets](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Users with the appropriate permissions can add and edit data in fact sheets, while administrators can customize and manage these permissions. By switching to table view in the inventory, you can perform inline editing across multiple fact sheets, and using the import option, you can update multiple fact sheets in bulk.").
